ast\_toolbox.samplers.ast\_vectorized\_sampler module
=====================================================

.. automodule:: ast_toolbox.samplers.ast_vectorized_sampler
   :members:
   :undoc-members:
   :show-inheritance:
